@@ -101,6 +101,11 @@ class CreateLoadBalancerTCPListenerRequest(RpcRequest):
 
 	def set_healthCheckInterval(self, healthCheckInterval):  # Integer
 		self.add_query_param('healthCheckInterval', healthCheckInterval)
+	def get_ProxyProtocolV2Enabled(self): # Boolean
+		return self.get_query_params().get('ProxyProtocolV2Enabled')
+
+	def set_ProxyProtocolV2Enabled(self, ProxyProtocolV2Enabled):  # Boolean
+		self.add_query_param('ProxyProtocolV2Enabled', ProxyProtocolV2Enabled)
 	def get_ConnectionDrain(self): # String
 		return self.get_query_params().get('ConnectionDrain')
 
